@@ -1,9 +1,5 @@
 # -*- coding: utf-8 -*-
 
-"""Created on 20.01.2020
-
-.. moduleauthor:: Paweł Pecio
-"""
 import pytest
 from pydantic import BaseModel
 from starsessions import InMemoryBackend
